<?php

namespace Drupal\Tests\ui_patterns_layouts\Functional;

use Drupal\Tests\ui_patterns\Functional\UiPatternsFunctionalTestBase;
use Drupal\Tests\ui_patterns\Traits\TestDataTrait;

/**
 * Test pattern preview rendering.
 *
 * @group ui_patterns_layouts
 */
class LayoutBuilderFieldFormatterRenderTest extends UiPatternsFunctionalTestBase {

  use TestDataTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'ui_patterns',
    'ui_patterns_test',
    'ui_patterns_layouts',
    'ui_patterns_field_formatters',
    'field_ui',
    'layout_builder',
    'block',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    if ($this->user) {
      $this->drupalCreateRole(['configure any layout'], 'custom_role');
      $this->user->addRole('custom_role');
      $this->user->save();
    }
  }

  /**
   * Test the form and the existence of the.
   */
  public function testContextInForm(): void {
    $this->createTestContentContentType();
    $assert_session = $this->assertSession();
    $config_import = $this->loadConfigFixture(__DIR__ . '/../fixtures/core.entity_view_display.node.page.full.yml');
    $ui_patterns_config = &$config_import['third_party_settings']['layout_builder']['sections'][0]['components']['6d778a84-cdc2-4a00-af66-54dab3ea2bf7']['configuration']['formatter']['settings']['ui_patterns'];
    $test_data = $this->loadTestDataFixture();
    $test_set = $test_data->getTestSet('context_exists_default');
    $ui_patterns_config = $this->buildUiPatternsConfig($test_set);
    $this->importConfigFixture(
      'core.entity_view_display.node.page.full',
      $config_import
    );
    $this->drupalGet('layout_builder/update/block/defaults/node.page.full/0/wrapper/6d778a84-cdc2-4a00-af66-54dab3ea2bf7');
    $assert_session->elementTextEquals('css', '.context-exists', $test_set['output']['props']['string']['value']);
  }

  /**
   * Tests preview and output of props.
   */
  public function testRender(): void {
    $assert_session = $this->assertSession();
    $config_import = $this->loadConfigFixture(__DIR__ . '/../fixtures/core.entity_view_display.node.page.full.yml');
    $ui_patterns_config = &$config_import['third_party_settings']['layout_builder']['sections'][0]['components']['6d778a84-cdc2-4a00-af66-54dab3ea2bf7']['configuration']['formatter']['settings']['ui_patterns'];
    $test_data = $this->loadTestDataFixture();
    $tests = [
      $test_data->getTestSet('textfield_default'),
    ];

    foreach ($tests as $test_set) {
      $node = $this->createTestContentNode('page', $test_set['entity'] ?? []);
      $ui_patterns_config = $this->buildUiPatternsConfig($test_set);
      $this->importConfigFixture(
        'core.entity_view_display.node.page.full',
        $config_import
      );
      $this->drupalGet('node/' . $node->id());
      $assert_session->statusCodeEquals(200);

      $assert_session->elementExists('css', '#ui-patterns-wrapper-wrapper');
      $assert_session->elementExists('css', '#ui-patterns-test-component');
      $this->validateRenderedComponent($test_set);
    }
  }

}
