<?php

namespace Drupal\Tests\ui_patterns_layouts\Kernel;

use Drupal\Component\Uuid\UuidInterface;
use Drupal\layout_builder\Section;

/**
 * Render test with field formatter.
 *
 * @group ui_patterns_layouts
 */
class RenderLayoutBuilderTest extends UIPatternsLayoutsTestBase {

  /**
   * Uuid service.
   *
   * @var \Drupal\Component\Uuid\UuidInterface
   */
  protected UuidInterface $uuidService;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    static::$additionalModules = ['ui_patterns_field_formatters', 'layout_builder'];
    parent::setUp();
    $this->uuidService = $this->container->get('uuid');
  }

  /**
   * Test render.
   *
   * @param string $entity_type_id
   *   Entity type id.
   * @param string $bundle
   *   Bundle.
   * @param string $field_name
   *   Field name.
   * @param array $field_items
   *   Field items.
   * @param array|null $display_component_settings
   *   Display component settings.
   * @param array $third_party_settings
   *   Third party settings.
   * @param string $expected_output
   *   Expected output.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   *
   * @dataProvider providerFieldMappingBundle
   */
  public function testRenderBundle(
    string $entity_type_id,
    string $bundle,
    string $field_name,
    array $field_items,
    ?array $display_component_settings,
    array $third_party_settings,
    string $expected_output,
  ) : void {
    $this->doTestRenderBundle($entity_type_id, $bundle, $field_name, $field_items, $display_component_settings, $third_party_settings, $expected_output);
  }

  /**
   * Callback data provider to test one slot, one prop.
   *
   * @return array[]
   *   Data provider for function testRender.
   */
  public function providerFieldMappingBundle(): array {
    $entity_type_id = "node";
    $bundle = self::$defaultNodeBundle;
    $field_type = 'text';
    $field_item = "Hello";
    $field_name = sprintf('field_%s', $field_type);
    $test_field_layout = [];

    $layoutBuilderSection = new Section(
      "ui_patterns:ui_patterns_tests_components:slot_test",
      [
        "label" => "alert layout",
        "context_mapping" => [
          "entity" => "layout_builder.entity",
        ],
        "ui_patterns" => [
          "component_id" => NULL,
          "variant_id" => NULL,
          "slots" => [],
          "props" => [],
        ],
      ],
      [],
      []
    );
    // Section component will  be added automatically with field config.
    $third_party_settings = [
      "field_layout" => [
        "id" => "ui_patterns:ui_patterns_tests_components:slot_test",
        "settings" => [
          "label" => "alert layout",
          "ui_patterns" => [
            "component_id" => NULL,
            "variant_id" => NULL,
            "slots" => [],
            "props" => [],
          ],
        ],
      ],
      "layout_builder" => [
        "enabled" => TRUE,
        "sections" => [$layoutBuilderSection],
      ],
    ];
    $test_field_layout[] = [
      $entity_type_id,
      $bundle,
      $field_name,
      [$field_name => [$field_item]],
      /*'display_component_settings' => */[
        "type" => "ui_patterns_component_per_item",
        "label" => "hidden",
        "settings" => [
          "ui_patterns" => [
            "component_id" => "ui_patterns_tests_components:slot_test",
            "variant_id" => NULL,
            "props" => [],
            "slots" => [
              "my_slot" => [
                "sources" => [
                  0 => [
                    "source_id" => "field_property:node:field_text:processed",
                    "_weight" => "0",
                  ],
                ],
              ],
            ],
          ],
        ],
      ],
      $third_party_settings,
      /*"expected" =>  */<<<EXPECTED
<div data-component-id="ui_patterns_tests_components:slot_test" class="test-class"><div><div>
<div data-component-id="ui_patterns_tests_components:slot_test" class="test-class">
<p>$field_item</p>
</div>
</div></div></div>
EXPECTED
    ];

    $test_field_layout[] = [
      $entity_type_id,
      $bundle,
      $field_name,
      [$field_name => [$field_item]],
      /*'display_component_settings' => */[
        "type" => "ui_patterns_component_per_item",
        "label" => "hidden",
        "settings" => [
          "ui_patterns" => [
            "component_id" => "ui_patterns_tests_components:slot_test",
            "variant_id" => NULL,
            "props" => [],
            "slots" => [
              "my_slot" => [
                "sources" => [
                  0 => [
                    "source_id" => "field_formatter:$entity_type_id:$bundle:field_text",
                    "source" => [
                      "type" => "text_default",
                    ],
                    "_weight" => "0",
                  ],
                ],
              ],
            ],
          ],
        ],
      ],
      $third_party_settings,
      /*"expected" =>  */<<<EXPECTED
<div data-component-id="ui_patterns_tests_components:slot_test" class="test-class"><div><div>
<div data-component-id="ui_patterns_tests_components:slot_test" class="test-class">
<p>$field_item</p>
</div>
</div></div></div>
EXPECTED
    ];
    return $test_field_layout;
  }

}
