<?php

namespace Drupal\Tests\ui_patterns_layouts\Kernel;

/**
 * Render test.
 *
 * @group ui_patterns_layouts
 */
class RenderTest extends UIPatternsLayoutsTestBase {

  /**
   * Test render.
   *
   * @param string $field_name
   *   Field name.
   * @param array $field_items
   *   Field items.
   * @param array $display_component_settings
   *   Display component settings.
   * @param array $third_party_settings
   *   Third party settings.
   * @param string $expected_output
   *   Expected output.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   *
   * @dataProvider providerFieldMapping
   */
  public function testRender(
    string $field_name,
    array $field_items,
    array $display_component_settings,
    array $third_party_settings,
    string $expected_output,
  ) : void {
    $this->doTestRender($field_name, $field_items, $display_component_settings, $third_party_settings, $expected_output);
  }

  /**
   * Callback data provider to test one slot, one prop.
   *
   * @return array[]
   *   Data provider for function testRender.
   */
  public function providerFieldMapping(): array {
    $field_type = 'text';
    $field_item = "Hello";
    $field_name = sprintf('field_%s', $field_type);
    $test_field_layout = [];
    $third_party_settings = [
      "field_layout" => [
        "id" => "ui_patterns:ui_patterns_tests_components:slot_test",
        "settings" => [
          "label" => "alert layout",
          "ui_patterns" => [
            "component_id" => NULL,
            "variant_id" => NULL,
            "slots" => [],
            "props" => [],
          ],
        ],
      ],
    ];
    $test_field_layout[] = [
      $field_name,
      [$field_name => [$field_item]],
      /*'display_component_settings' => */[
        "type" => "text_default",
        "label" => "hidden",
        "settings" => [],
        "third_party_settings" => [],
        "weight" => "0",
        "region" => "my_slot",
      ],
      $third_party_settings,
      '<div data-component-id="ui_patterns_tests_components:slot_test" class="test-class"><div><div><p>' . $field_item . '</p></div></div></div>',
    ];

    return $test_field_layout;
  }

}
