<?php

declare(strict_types=1);

namespace Drupal\ui_patterns\Plugin\UiPatterns\Source;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\ui_patterns\Attribute\Source;
use Drupal\ui_patterns\SourcePluginBase;

/**
 * Plugin implementation of the source.
 */
#[Source(
  id: 'list_textarea',
  label: new TranslatableMarkup('Textarea for list'),
  description: new TranslatableMarkup('One item by line.'),
  prop_types: ['list']
)]
class ListTextareaWidget extends SourcePluginBase {

  /**
   * {@inheritdoc}
   */
  public function getPropValue(): mixed {
    $long_text = $this->getSetting('value') ?? '';
    return preg_split("/\r\n|\n|\r/", $long_text);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    $form = parent::settingsForm($form, $form_state);
    $items = $this->getSetting('value');
    if (is_array($items)) {
      $items = implode("\r", $items);
    }
    $form['value'] = [
      '#type' => 'textarea',
      '#default_value' => $items,
      "#description" => $this->t("One item by line"),
    ];
    $this->addRequired($form['value']);
    return $form;
  }

}
