<?php

declare(strict_types=1);

namespace Drupal\Tests\ui_patterns\Kernel;

use Drupal\Core\Plugin\Context\EntityContext;
use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\ui_patterns\Traits\RunSourcePluginTestTrait;
use Drupal\Tests\ui_patterns\Traits\TestContentCreationTrait;

/**
 * Base class to test source plugins.
 *
 * @group ui_patterns
 */
class SourcePluginsTestBase extends KernelTestBase {

  use RunSourcePluginTestTrait;
  use TestContentCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'user',
    'text',
    'field',
    'node',
    'ui_patterns',
    'ui_patterns_test',
    'datetime',
    'filter',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installEntitySchema('node');
    $this->installEntitySchema('user');
    $this->installConfig(['system', 'filter']);
    $this->createTestContentContentType();
  }

  /**
   * {@inheritdoc}
   */
  protected function getSourceContexts(array $test_set = []): array {
    $context = [];
    if (isset($test_set['entity'])) {
      $entity = $this->createTestContentNode('page', is_array($test_set['entity']) ? $test_set['entity'] : []);
      $context['entity'] = EntityContext::fromEntity($entity);
    }
    return $context;
  }

}
